@@ -1,6 +1,8 @@
 eqwma <-
-function(x, length=5, lag=1, start=1, p=1, log=FALSE, abs=FALSE)
+function(x, length=5, lag=1, start=1, p=1,
+  log=FALSE, abs=FALSE, as.vector=TRUE)
 {
+#zoo related:
 if(is.zoo(x)){
   xindex <- index(x)
   x <- coredata(as.vector(x))
@@ -10,12 +12,13 @@ if(is.zoo(x)){
   zoochk <- FALSE
 }
 
+#compute eqwma:
 xn <- length(x)
 x <- na.trim(x, sides="left")
 xnadj <- length(x)
 if(xn > xnadj){nachk <- TRUE}else{nachk <- FALSE}
 if(abs){xabs <- abs(x)}else{xabs <- x}
-if(p!=1){xabsp <- xabs^p}else{xabsp <- x}
+if(p!=1){xabsp <- xabs^p}else{xabsp <- xabs}
 
 out <- NULL
 for(j in 1:length(length)){
@@ -29,20 +32,7 @@ for(j in 1:length(length)){
   out <- cbind(out, movavg)
 }
 
-##alternative/future/more efficient approach:
-#out <- NULL
-#for(j in 1:length(length)){
-#  movavg <- rollmean(xabsp, length[j], na.pad=TRUE, align="r")
-#  if(length[j] > 1){
-#    movavgmean <- mean(movavg, na.rm=TRUE)
-#    xabsp.pre <- c( rep(movavgmean, I(length[j]-1)), xabsp[1:I(length[j]-1)] )
-#    movavg.pre <- rollmean(xabsp.pre, length[j], na.pad=FALSE, align="r")
-#    movavg[1:I(length[j]-1)] <- movavg.pre
-#  }
-#  movavg <- c(rep(NA,lag), as.vector(movavg[1:I(length(movavg)-lag)]))
-#  out <- cbind(out, movavg)
-#}
-
+#apply log?:
 if(log){
   out <- log(out)
   colnames(out) <- paste("logEqWMA(", length, ")", sep="")
@@ -50,8 +40,10 @@ if(log){
   colnames(out) <- paste("EqWMA(", length, ")", sep="")
 }
 if(nachk) out <- rbind( matrix(NA, I(xn-xnadj), dim(out)[2]), out)
-if( dim(out)[2]==1 ) out <- as.vector(out)
-if(zoochk) out <- zoo(out, order.by=xindex)
+if(as.vector){
+  if( dim(out)[2]==1 ){ out <- as.vector(out) }
+}
+if(zoochk){ out <- zoo(out, order.by=xindex) }
 
 return(out)
 }
